==> odoo_18.0.20260103.zip: odoo-18.0.post20260103/odoo/addons/pos_hr/static/tests/tours/utils/pos_hr_helpers.js <==
import * as SelectionPopup from "@point_of_sale/../tests/tours/utils/selection_popup_util";
import * as Dialog from "@point_of_sale/../tests/tours/utils/dialog_util";
import * as NumberPopup from "@point_of_sale/../tests/tours/utils/number_popup_util";
import { negate } from "@point_of_sale/../tests/tours/utils/common";

export function clickLoginButton() {
    return [
        {
            content: "click login button",
            trigger: ".login-overlay .select-cashier",
            run: "click",
        },
    ];
}
export function clickCashierName() {
    return [
        {
            content: "click cashier name",
            trigger: ".cashier-name",
            run: "click",
        },
    ];
}
export function loginScreenIsShown() {
    return [
        {
            content: "login screen is shown",
            trigger: ".login-overlay .screen-login",
        },
    ];
}
export function loginScreenIsNotShown() {
    return [
        {
            content: "login screen is not shown",
            trigger: negate(".login-overlay .screen-login"),
        },
    ];
}
export function cashierNameIs(name) {
    return [
        {
            isActive: ["desktop"],
            content: `logged cashier is '${name}'`,
            trigger: `.pos .oe_status .username:contains("${name}")`,
        },
        {
            isActive: ["mobile"],
            content: `logged cashier is '${name}'`,
            trigger: `.pos .oe_status img[alt="${name}"]`,
        },
    ];
}
export function login(name, pin) {
    const res = [...clickLoginButton(), ...SelectionPopup.has(name, { run: "click" })];
    if (!pin) {
        return res;
    }
    return res.concat(enterPin(pin));
}
export function enterPin(pin) {
    return [...NumberPopup.enterValue(pin), ...NumberPopup.isShown("••••"), Dialog.confirm()];
}
export function clickLockButton() {
    return {
        content: "Click on the menu button",
        trigger: ".pos-rightheader i.fa-unlock",
        run: "click",
    };
}

export function refreshPage() {
    return [
        {
            trigger: ".pos",
            run: () => {
                window.location.reload();
            },
            expectUnloadPage: true,
        },
    ];
}

==> odoo_19.0.20250919.zip: odoo-19.0.post20250919/odoo/addons/pos_hr/static/tests/tours/utils/pos_hr_helpers.js <==
import * as SelectionPopup from "@point_of_sale/../tests/generic_helpers/selection_popup_util";
import * as Dialog from "@point_of_sale/../tests/generic_helpers/dialog_util";
import * as NumberPopup from "@point_of_sale/../tests/generic_helpers/number_popup_util";

export function clickLoginButton() {
    return [
        {
            content: "click login button",
            trigger: ".login-overlay .select-cashier",
            run: "click",
        },
    ];
}
export function clickCashierName() {
    return [
        {
            content: "click cashier name",
            trigger: ".cashier-name",
            run: "click",
        },
    ];
}
export function loginScreenIsShown() {
    return [
        {
            content: "login screen is shown",
            trigger: ".login-overlay .screen-login",
        },
    ];
}
export function login(name, pin) {
    const res = [...clickLoginButton(), ...SelectionPopup.has(name, { run: "click" })];
    if (!pin) {
        return res;
    }
    return res.concat([
        ...NumberPopup.enterValue(pin),
        ...NumberPopup.isShown("••••"),
        Dialog.confirm(),
    ]);
}
export function clickLockButton() {
    return {
        content: "Click on the menu button",
        trigger: ".pos-rightheader i.fa-unlock",
        run: "click",
    };
}

export function refreshPage() {
    return [
        {
            trigger: ".pos",
            run: () => {
                window.location.reload();
            },
            expectUnloadPage: true,
        },
    ];
}
